<TS language="et" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Paremkliki aadressi või sildi muutmiseks</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Loo uus aadress</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Uus</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopeeri märgistatud aadress vahemällu</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopeeri</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>S&amp;ulge</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Kustuta valitud aadress nimekirjast</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Otsimiseks sisesta märgis või aadress</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Ekspordi kuvatava vahelehe sisu faili</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Ekspordi</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Kustuta</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Vali aadress millele mündid saata</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Vali aadress müntide vastuvõtmiseks</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>V&amp;ali</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Saatvad aadressid</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Vastuvõtvad aadressid</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Need on sinu Bitcoin aadressid maksete saatmiseks. Ennem müntide saatmist kontrolli alati summat ja makse saaja aadressi.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopeeri Aadress</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopeeri &amp;Silt</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muuda</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Ekspordi Aadresside Nimekiri</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komadega eraldatud väärtuste fail (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksport ebaõnnestus.</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Tõrge aadressi nimekirja salvestamisel %1. Palun proovi uuesti.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Silt</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Aadress</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(silt puudub)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Salafraasi dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Sisesta parool</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Uus parool</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Korda uut parooli</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Näita salafraasi</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Krüpteeri rahakott</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Antud operatsioon vajab rahakoti lahtilukustamiseks salafraasi.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ava rahakoti lukk</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Antud operatsioon vajab rahakoti dekrüpteerimiseks salafraasi.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dekrüpteeri rahakott</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Muuda parooli</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Kinnita rahakoti krüpteerimine.</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Hoiatus:Kui sa krüpteerid oma rahakoti ja kaotad salafraasi, siis sa&lt;b&gt;KAOTAD OMA BITCOINID&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Kas oled kindel, et soovid rahakoti krüpteerida?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Rahakott krüpteeritud</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Sisesta rahakotile uus salafraas.&lt;br/&gt;Kasuta salafraasi millles on&lt;b&gt;kümme või rohkem juhuslikku sümbolit&lt;b&gt;,või&lt;b&gt;kaheksa või rohkem sõna&lt;b/&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Sisesta rahakoti vana salafraas ja uus salafraas.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>Pea meeles, et rahakoti krüpteerimine ei välista bitcoinide vargust, kui sinu arvuti on nakatunud pahavaraga.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Krüpteeritav rahakott</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Rahakott krüpteeritakse.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Rahakott krüpteeritud.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>TÄHTIS: Kõik varasemad rahakoti varundfailid tuleks üle kirjutada äsja loodud krüpteeritud rahakoti failiga. Turvakaalutlustel tühistatakse krüpteerimata rahakoti failid alates uue, krüpteeritud rahakoti, kasutusele võtust.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Rahakoti krüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Rahakoti krüpteerimine ebaõnnestus sisemise vea tõttu. Sinu rahakotti ei krüpteeritud.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Sisestatud paroolid ei kattu.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Rahakoti lahtilukustamine ebaõnnestus</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Rahakoti dekrüpteerimiseks sisestatud salafraas ei ole õige.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Rahakoti dekrüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Rahakoti parooli vahetus õnnestus.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Hoiatus:Klaviatuuri suurtähelukk on peal.</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Võrgumask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Blokeeritud kuni</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signeeri &amp;sõnum</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Võrguga sünkroniseerimine...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Ülevaade</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Kuva rahakoti üld-ülevaade</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Tehingud</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Sirvi tehingute ajalugu</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>V&amp;älju</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Välju rakendusest</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Teave %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Näita informatsiooni %1 kohta</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Teave &amp;Qt kohta</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Kuva Qt kohta käiv info</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Valikud...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Muuda %1 seadeid</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Krüpteeri Rahakott</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Varunda Rahakott</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Salafraasi muutmine</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Ava &amp;URI...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>Loo rahakott</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>Loo uus rahakott</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Rahakott:</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Kõvakettal olevate plokkide reindekseerimine...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Saada münte Bitcoini aadressile</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Varunda rahakott teise asukohta</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Rahakoti krüpteerimise salafraasi muutmine</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Kontrolli sõnumit...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Saada</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Võta vastu</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Näita / Peida</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Näita või peida peaaken</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Krüpteeri oma rahakoti privaatvõtmed</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Omandi tõestamiseks allkirjasta sõnumid oma Bitcoini aadressiga</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Kinnita sõnumid kindlustamaks et need allkirjastati määratud Bitcoini aadressiga</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Seaded</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Abi</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Vahelehe tööriistariba</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Loo maksepäring (genereerib QR koodid ja bitcoini: URId)</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Käsurea valikud</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network</source>
        <translation><numerusform>%n aktiivne ühendus Bitcoini võrku</numerusform><numerusform>%n aktiivset ühendust Bitcoini võrku</numerusform></translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Kõvakettal olevate plokkide indekseerimine...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Kõvakettal olevate plokkide töötlemine...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>Töödeldud %n plokk transaktsioonide ajaloost.</numerusform><numerusform>Töödeldud %n plokki transaktsioonide ajaloost.</numerusform></translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 ajast maas</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Viimane saabunud blokk loodi %1 tagasi.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Hilisemad transaktsioonid ei ole veel nähtavad.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Hoiatus</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatsioon</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ajakohane</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Aken</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 klient</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Jõuan järgi...</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Tõrge %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Kuupäev: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Summa: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tüüp: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>&amp;Märgis: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Aadress: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Saadetud tehing</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Sisenev tehing</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Rahakott on &lt;b&gt;krüpteeritud&lt;/b&gt; ning hetkel &lt;b&gt;avatud&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Rahakott on &lt;b&gt;krüpteeritud&lt;/b&gt; ning hetkel &lt;b&gt;suletud&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Kogus:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasu:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Puru:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Peale tehingutasu:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vahetusraha:</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Puu režiim</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Loetelu režiim</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Vastuvõetud märgisega</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Vastuvõetud aadressiga</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Kinnitused</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Kinnitatud</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopeeri aadress</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopeeri märgis</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopeeri transaktsiooni ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopeeri tehingutasu</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopeeri baidid</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopeeri puru</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopeeri vahetusraha</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 lukustatud)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>jah</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ei</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(silt puudub)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(vahetusraha)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Rahakott</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Muuda aadressi</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Märgis</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Aadress</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Uus saatev aadress</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Muuda vastuvõtvat aadressi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Muuda saatvat aadressi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>Sisestatud aadress "%1" ei ole korrektne Bitcoin aadress.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Rahakoti lahtilukustamine ebaõnnestus.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Uue võtme genereerimine ebaõnnestus.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>nimi</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versioon</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Käsurea valikud</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Tere tulemast</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Viimane ploki aeg</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Peida</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Valikud</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Peamine</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Taasta kõik klientprogrammi seadete vaikeväärtused.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Lähtesta valikud</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Võrk</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>R&amp;ahakott</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Ekspert</translation>
    </message>
    <message>
        <source>Automatically open the Bitcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Bitcoini kliendi pordi automaatne avamine ruuteris. Toimib, kui sinu ruuter aktsepteerib UPnP ühendust.</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Suuna port &amp;UPnP kaudu</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Proxi &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxi port (nt 9050)</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Aken</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Minimeeri systray alale.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimeeri systray alale</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimeeri sulgemisel</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Kuva</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Kasutajaliidese &amp;keel:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Summade kuvamise &amp;Unit:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Vali liideses ning müntide saatmisel kuvatav vaikimisi alajaotus.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Katkesta</translation>
    </message>
    <message>
        <source>default</source>
        <translation>vaikeväärtus</translation>
    </message>
    <message>
        <source>none</source>
        <translation>puudub</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Kinnita valikute algseadistamine</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Sisestatud kehtetu proxy aadress.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Kuvatav info ei pruugi olla ajakohane. Ühenduse loomisel süngitakse sinu rahakott automaatselt Bitcoin võrgustikuga, kuid see toiming on hetkel lõpetamata.</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Ootel:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Ebaküps:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Mitte aegunud mine'itud jääk</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Kokku:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Hiljutised transaktsioonid</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>or</source>
        <translation>või</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Maksepäringu tõrge</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation>Bitcoin ei käivitu: vajuta-maksa toiming</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI käsitsemine</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Sent</source>
        <translation>Saadetud</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Vastu võetud</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation>%1 ms</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n tund</numerusform><numerusform>%n tundi</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n päev</numerusform><numerusform>%n päeva</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n nädal</numerusform><numerusform>%n nädalat</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 ja %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n aasta</numerusform><numerusform>%n aastat</numerusform></translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Tõrge %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tundmatu</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Salvesta Pilt...</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Kopeeri Pilt</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>URI liiga pikk, proovi vähendada märke / sõnumi pikkust.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Tõrge URI'st QR koodi loomisel</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Salvesta QR Kood</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Kliendi versioon</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informatsioon</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Üldine</translation>
    </message>
    <message>
        <source>Using BerkeleyDB version</source>
        <translation>Kasutab BerkeleyDB versiooni</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Käivitamise hetk</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Võrk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Ühenduste arv</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokiahel</translation>
    </message>
    <message>
        <source>Memory usage</source>
        <translation>Mälu kasutus</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation>&amp;Lähtesta</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Vastu võetud</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Saadetud</translation>
    </message>
    <message>
        <source>Direction</source>
        <translation>Suund</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versioon</translation>
    </message>
    <message>
        <source>Synced Headers</source>
        <translation>Sünkroniseeritud Päised</translation>
    </message>
    <message>
        <source>Synced Blocks</source>
        <translation>Sünkroniseeritud Plokid</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Teenused</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation>Pingi Aeg</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Viimane ploki aeg</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ava</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsool</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Võrgu Liiklus</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Silumise logifail</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Puhasta konsool</translation>
    </message>
    <message>
        <source>never</source>
        <translation>mitte kunagi</translation>
    </message>
    <message>
        <source>Inbound</source>
        <translation>Sisenev</translation>
    </message>
    <message>
        <source>Outbound</source>
        <translation>Väljuv</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Teadmata</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Kogus:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Märgis</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Sõnum:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Puhasta kõik vormi väljad.</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Näita</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopeeri märgis</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation>Kopeeri sõnum</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Rahakoti lahtilukustamine ebaõnnestus.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Märgis:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Sõnum:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>Rahakott:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Kopeeri Aadress</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Salvesta Pilt...</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Makse Informatsioon</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Silt</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Sõnum</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(silt puudub)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(sõnum puudub)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Müntide saatmine</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Sisendid...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automaatselt valitud</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Liiga suur summa</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kogus:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasu:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Peale tehingutasu:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vahetusraha:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Tehingu tasu:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Vali...</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>kilobaidi kohta</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Peida</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Soovitatud:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Saatmine mitmele korraga</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Lisa &amp;Saaja</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Puhasta kõik vormi väljad.</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Puru:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Puhasta &amp;Kõik</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Jääk:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Saatmise kinnitamine</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;aada</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopeeri tehingutasu</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopeeri baidid</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopeeri puru</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopeeri vahetusraha</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Oled kindel, et soovid saata?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>või</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tehingutasu</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Müntide saatmise kinnitamine</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>Saaja aadress ei ole korrektne. Palun kontrolli üle.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Makstav summa peab olema suurem kui 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Summa ületab jäägi.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Summa koos tehingu tasuga %1 ületab sinu jääki.</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Maksepäring aegunud.</translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>Hoiatus: Ebakorrektne Bitcoin aadress</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(silt puudub)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>S&amp;umma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Maksa &amp;:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Märgis</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Vali eelnevalt kasutatud aadress</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Kleebi aadress vahemälust</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>S&amp;ubtract fee from amount</source>
        <translation>L&amp;ahuta tehingutasu summast</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Sõnum:</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Maksa :</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down...</source>
        <translation>%1 lülitub välja...</translation>
    </message>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation>Ära lülita arvutit välja ennem kui see aken on kadunud.</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signatuurid - Allkirjasta / Kinnita Sõnum</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Allkirjastamise teade</translation>
    </message>
    <message>
        <source>The Bitcoin address to sign the message with</source>
        <translation>Bitcoin aadress millega sõnum allkirjastada</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Vali eelnevalt kasutatud aadress</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Kleebi aadress vahemälust</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Sisesta siia allkirjastamise sõnum</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Allkiri</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopeeri praegune signatuur vahemällu</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation>Allkirjasta sõnum Bitcoini aadressi sulle kuulumise tõestamiseks</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Allkirjasta &amp;Sõnum</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Tühjenda kõik sõnumi allkirjastamise väljad</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Puhasta &amp;Kõik</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Kinnita Sõnum</translation>
    </message>
    <message>
        <source>The Bitcoin address the message was signed with</source>
        <translation>Bitcoin aadress millega sõnum on allkirjastatud</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation>Kinnita sõnum tõestamaks selle allkirjastatust määratud Bitcoini aadressiga.</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Kinnita &amp;Sõnum</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Tühjenda kõik sõnumi kinnitamise väljad</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Allkirja loomiseks vajuta "Allkirjasta Sõnum"</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Sisestatud aadress ei ole korrektne</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Palun kontrolli aadressi ja proovi uuesti.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Sisestatud aadress ei viita võtmele.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Rahakoti lahtilukustamine on katkestatud.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Sisestatud aadressi privaatvõti pole saadaval.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Sõnumi allkirjastamine ebaõnnestus.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Sõnum allkirjastatud.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Allkirja ei õnnestunud dekodeerida.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Palun kontrolli allkirja ja proovi uuesti.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Allkiri ei vastanud sõnumi krüptoräsile.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Sõnumi verifitseerimine ebaõnnestus.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Sõnum verifitseeritud.</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Avatud kuni %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/kinnitamata</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 kinnitust</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Olek</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Allikas</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Genereeritud</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Saatja</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tundmatu</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Saaja</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>oma aadress</translation>
    </message>
    <message>
        <source>label</source>
        <translation>märgis</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Krediit</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>pole vastu võetud</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Deebet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tehingutasu</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto summa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Sõnum</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentaar</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>Transaktsiooni ID</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>Kaupleja</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Debug'imise info</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Tehing</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation>Sisendid</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>true</source>
        <translation>tõene</translation>
    </message>
    <message>
        <source>false</source>
        <translation>väär</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Paan kuvab tehingu detailid</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tüüp</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Silt</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Avatud kuni %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Kinnitamata</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Kinnitatud (%1 kinnitust)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Loodud, kuid aktsepteerimata</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Saadud koos</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Kellelt saadud</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Saadetud</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Makse iseendale</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Mine'itud</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n/a)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(silt puudub)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Tehingu staatus. Kinnituste arvu kuvamiseks liigu hiire noolega selle peale.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Tehingu saamise kuupäev ning kellaaeg.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tehingu tüüp.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Jäägile lisatud või eemaldatud summa.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Kõik</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Täna</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Käesolev nädal</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Käimasolev kuu</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Eelmine kuu</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Käimasolev aasta</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Vahemik...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Saadud koos</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Saadetud</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Iseendale</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Mine'itud</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimaalne summa</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopeeri aadress</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopeeri märgis</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri summa</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopeeri transaktsiooni ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Märgise muutmine</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Kuva tehingu detailid</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Komadega eraldatud väärtuste fail (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Kinnitatud</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tüüp</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Silt</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Aadress</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksport ebaõnnestus.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Vahemik:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>saaja</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>Loo uus rahakott</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Müntide saatmine</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Ekspordi</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Ekspordi kuvatava vahelehe sisu faili</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Viga</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Varunda Rahakott</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Rahakoti Andmed (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Varundamine Ebaõnnestus</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation>Varundamine õnnestus</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation>See on test-versioon - kasutamine omal riisikol - ära kasuta mining'uks ega kaupmeeste programmides</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation>Tuvastati vigane bloki andmebaas</translation>
    </message>
    <message>
        <source>Do you want to rebuild the block database now?</source>
        <translation>Kas soovid bloki andmebaasi taastada?</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation>Tõrge bloki andmebaasi käivitamisel</translation>
    </message>
    <message>
        <source>Error initializing wallet database environment %s!</source>
        <translation>Tõrge rahakoti keskkonna %s käivitamisel!</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation>Tõrge bloki baasi lugemisel</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation>Tõrge bloki andmebaasi avamisel</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Pordi kuulamine nurjus. Soovikorral kasuta -listen=0.</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>Kontrollin blokke...</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Tehingu allkirjastamine ebaõnnestus</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation>Tehingu summa on tasu maksmiseks liiga väikene</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Tehingu summa liiga väikene</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Tehing liiga suur</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Kirjeldatud tundmatu võrgustik -onlynet'is: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Liiga suur summa</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Klotside indeksi laadimine...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Rahakoti laadimine...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Rahakoti vanandamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Üleskaneerimine...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Laetud</translation>
    </message>
</context>
</TS>